@@ -2,9 +2,23 @@ import attr
 import cattr
 import json
 import logging
-from cachetools import LRUCache
+from cachetools import LRUCache, cachedmethod
+from cachetools.keys import hashkey
+from functools import partial
 from requests import Response, Session
-from typing import Any, Callable, MutableMapping, Optional, Type, TypeVar, Union
+from operator import attrgetter
+from typing import (
+    Any,
+    Callable,
+    Generic,
+    List,
+    MutableMapping,
+    Optional,
+    Type,
+    TypeVar,
+    Union,
+    TYPE_CHECKING,
+)
 
 from dapodik.exception import DapodikResponseError, ServerTidakMerespon
 from dapodik.message import DapodikMessage
@@ -13,6 +27,9 @@ from dapodik.utils.parser import register_hooks
 
 T = TypeVar("T")
 
+if TYPE_CHECKING:
+    from dapodik import Dapodik
+
 
 class BaseDapodik(object):
     def __init__(self, base_url: str = "http://localhost:5774/"):
@@ -259,3 +276,46 @@ class BaseDapodik(object):
     _find = staticmethod(find_in)
     _register_hooks = staticmethod(register_hooks)
     _query = staticmethod(make_query)
+
+
+BD = TypeVar("BD", bound=BaseDapodik)
+
+
+class BaseProp(Generic[T]):
+    filename: str
+    cl: Type[T]
+    d: BD
+
+    def __call__(self) -> T:
+        return self.d._get_rows(path=self.filename, cl=self.cl)
+
+
+@attr.dataclass
+class BasePRest(Generic[T]):
+    filename: str
+    cl: Type[T]
+    dapodik: "Dapodik"
+    key: str = ""
+
+    def __attrs_post_init__(self) -> None:
+        if not self.key:
+            self.key = self.filename.lower() + "_id"
+
+    @cachedmethod(
+        attrgetter("dapodik.cache"), key=partial(hashkey, attrgetter("filename"))
+    )
+    def __call__(
+        self,
+        id: str = None,
+        page: int = 1,
+        start: int = 0,
+        limit: int = 50,
+    ) -> List[T]:
+        return self.dapodik._get_rest(
+            self.filename,
+            List[self.cl],
+            page,
+            start,
+            limit,
+            query={self.key: id} if id else {},
+        )
