@@ -1,12 +1,11 @@
+import attr
 from datetime import datetime
 from typing import Optional
 
-import attr
-
 
 @attr.dataclass(frozen=True, slots=True)
 class JenisKeluar:
-    jenis_keluar_id: str
+    jenis_keluar_id: int
     ket_keluar: str
     keluar_pd: str
     keluar_ptk: str
@@ -14,3 +13,6 @@ class JenisKeluar:
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
+
+    def __str__(self):
+        return self.ket_keluar
