@@ -1,19 +1,17 @@
+import attr
 from datetime import datetime
 from typing import Optional
 
-import attr
-
 
 @attr.dataclass(frozen=True, slots=True)
 class Jurusan:
-    jurusan_id: str
+    jurusan_id: int
     nama_jurusan: str
     untuk_sma: str
     untuk_smk: str
     untuk_pt: str
     untuk_slb: str
     untuk_smklb: str
-    jenjang_pendidikan_id: Optional[str]
     jurusan_induk: Optional[str]
     level_bidang_id: str
     create_date: datetime
