@@ -53,3 +53,6 @@ class Bangunan:
     soft_delete: Optional[str] = None
     last_sync: Optional[datetime] = None
     updater_id: Optional[str] = None
+
+    def __str__(self) -> str:
+        return self.nama
