@@ -23,3 +23,6 @@ class Buku:
     soft_delete: Optional[str] = None
     last_sync: Optional[datetime] = None
     updater_id: Optional[str] = None
+
+    def __str__(self) -> str:
+        return self.nm_buku
