@@ -42,3 +42,6 @@ class Ruang:
     soft_delete: Optional[str] = None
     last_sync: Optional[datetime] = None
     updater_id: Optional[str] = None
+
+    def __str__(self) -> str:
+        return self.nm_ruang
