@@ -17,3 +17,6 @@ class Semester:
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
+
+    def __str__(self) -> str:
+        return self.nama
