@@ -26,7 +26,7 @@ def clean_response(data: str) -> str:
     return data
 
 
-def make_query(*args, **kwargs) -> dict:
+def make_query(*_, **kwargs) -> dict:
     query = dict()
     for key, val in dict(kwargs).items():
         if val is not None:
